@@ -53,7 +53,7 @@ class DictObject(object):
         return self._data
 
 
-def xml_subelement_attr(xml_elem, subelement, convert=None, attribute="value"):
+def xml_subelement_attr(xml_elem, subelement, convert=None, attribute="value", default=None, quiet=False):
     """
     Search for a sub-element and return the value of its attribute.
 
@@ -72,22 +72,33 @@ def xml_subelement_attr(xml_elem, subelement, convert=None, attribute="value"):
     :param subelement: Name of the sub-element to search for
     :param convert: if not None, a callable to perform the conversion of this attribute to a certain object type
     :param attribute: name of the attribute to get
+    :param default: default value if the subelement or attribute is not found
+    :param quiet: if True, don't raise exception from conversions, return default instead
     :return: value of the attribute or ``None`` in error cases
 
     """
     if xml_elem is None or not subelement:
         return None
 
-    value = None
     subel = xml_elem.find(subelement)
-    if subel is not None:
+    if subel is None:
+        value = default
+    else:
         value = subel.attrib.get(attribute)
-        if convert and value is not None:
-            value = convert(value)
+        if value is None:
+            value = default
+        elif convert:
+            try:
+                value = convert(value)
+            except:
+                if quiet:
+                    value = default
+                else:
+                    raise
     return value
 
 
-def xml_subelement_attr_list(xml_elem, subelement, convert=None, attribute="value"):
+def xml_subelement_attr_list(xml_elem, subelement, convert=None, attribute="value", default=None, quiet=False):
     """
     Search for sub-elements and return a list of the specified attribute.
 
@@ -105,6 +116,8 @@ def xml_subelement_attr_list(xml_elem, subelement, convert=None, attribute="valu
     :param subelement: name of the sub-element to search for
     :param convert: if not None, a callable used to perform the conversion of this attribute to a certain object type
     :param attribute: name of the attribute to get
+    :param default: default value to use if an attribute is missing
+    :param quiet: if True, don't raise exceptions from conversions, instead use the default value
     :return: list containing the values of the attributes or ``None`` in error cases
     """
     if xml_elem is None or not subelement:
@@ -114,14 +127,22 @@ def xml_subelement_attr_list(xml_elem, subelement, convert=None, attribute="valu
     res = []
     for e in subel:
         value = e.attrib.get(attribute)
-        if convert and value is not None:
-            value = convert(value)
+        if value is None:
+            value = default
+        elif convert:
+            try:
+                value = convert(value)
+            except:
+                if quiet:
+                    value = default
+                else:
+                    raise
         res.append(value)
 
     return res
 
 
-def xml_subelement_text(xml_elem, subelement, convert=None):
+def xml_subelement_text(xml_elem, subelement, convert=None, default=None, quiet=False):
     """
     Return the text of the specified subelement
 
@@ -138,17 +159,28 @@ def xml_subelement_text(xml_elem, subelement, convert=None):
     :param xml_elem: search the children nodes of this element
     :param subelement: name of the subelement whose text will be retrieved
     :param convert: if not None, a callable used to perform the conversion of the text to a certain object type
+    :param default: default value if subelement is not found
+    :param quiet: if True, don't raise exceptions from conversions, instead use the default value
     :return: The text associated with the sub-element or ``None`` in case of error
     """
     if xml_elem is None or not subelement:
         return None
 
-    text = None
     subel = xml_elem.find(subelement)
-    if subel is not None:
+    if subel is None:
+        text = default
+    else:
         text = subel.text
-        if convert and text is not None:
-            text = convert(text)
+        if text is None:
+            text = default
+        elif convert:
+            try:
+                text = convert(text)
+            except:
+                if quiet:
+                    text = default
+                else:
+                    raise
     return text
 
 
